# aicastle
AI Castle Package

homepage : https://aicastle.io
email : dev@aicastle.io

## Installation
```
python -m pip install aicastle
```

## upgrade
```
python -m pip install --upgrade aicastle
```

## 개발 시 설치 (editable mode)
- 패키지가 설치되는 대신 해당 디렉터리가 심볼릭 링크로 연결.
- `pip install -e .`
